"""
hudai.resources.model_score
"""
from ..helpers.resource import Resource


class ModelScoreResource(Resource):
    def __init__(self, client):
        Resource.__init__(self, client, base_path='/articles/scores')
        self.resource_name = 'ModelScore'

    def list(self,
             article_id=None,
             model=None,
             ):
        return self._list(
            article_id=article_id,
            model=model,
        )

    def create(self,
               article_id=None,
               model_id=None,
               model_name=None,
               model_score=None,
               model_version=None,
               model_url=None,
               data_url=None,
               ):
        return self._create(
            article_id=article_id,
            model_id=model_id,
            model_name=model_name,
            model_score=model_score,
            model_version=model_version,
            model_url=model_url,
            data_url=data_url,
        )

    def fetch(self, entity_id):
        return self._fetch(entity_id)

    def upsert(self,
               article_id=None,
               model_id=None,
               model_name=None,
               model_score=None,
               model_version=None,
               model_url=None,
               data_url=None,
               ):
        return self._upsert(
            article_id=article_id,
            model_id=model_id,
            model_name=model_name,
            model_score=model_score,
            model_version=model_version,
            model_url=model_url,
            data_url=data_url,
        )

    def delete(self, entity_id):
        return self._delete(entity_id)



"""
hudai.resources.user_template
"""
from ..helpers.resource import Resource


class UserTemplateResource(Resource):
    def __init__(self, client):
        Resource.__init__(
            self, client, base_path='/users/templates')
        self.resource_name = 'UserTemplate'

    def list(self, user_id=None, content_type=None, name=None, page=None):
        query_params = self._set_limit_offset({
            'content_type': content_type,
            'name': name,
            'page': page,
            'user_id': user_id
        })

        return self.http_get('/', query_params=query_params)

    def create(self, content_type, markdown, name, user_id=None):
        return self.http_post('/',
                              data={'markdown': markdown,
                                    'name': name,
                                    'content_type': content_type,
                                    'user_id': user_id})

    def fetch(self, template_id):
        return self.http_get('/{id}',
                             params={'id': template_id})

    def delete(self, template_id):
        return self.http_delete('/{id}',
                                params={'id': template_id})



"""
hudai.resources.conference_speaker
"""
from ..helpers.resource import Resource


class ConferenceSpeakerResource(Resource):
    def __init__(self, client):
        Resource.__init__(self, client, base_path='/people/conferences/speakers')
        self.resource_name = 'ConferenceSpeaker'

    def list(self, conference_id, page=None):
        query_params = self._set_limit_offset({'page': page})

        return self.http_get('/', params={'conference_id': conference_id},
                                  query_params=query_params)

    def create(self, conference_id, person_id):
        return self.http_post('/', data={'person_id': person_id, 'conference_id': conference_id})

    def fetch(self, entity_id):
        return self.http_get('/{id}',
                             params={'id': entity_id})

    def delete(self, entity_id):
        return self.http_delete('/{id}',
                                params={'id': entity_id})



"""
hudai.resources.action_item
"""
from ..helpers.resource import Resource


class ActionItemResource(Resource):
    def __init__(self, client):
        Resource.__init__(self, client, base_path='/users/action-items')
        self.resource_name = 'ActionItem'

    def list(self, created_after=None,
                   created_before=None,
                   entity_id=None,
                   user_id=None,
                   company_ids=None,
                   person_ids=None,
                   completed=None,
                   completed_before=None,
                   completed_after=None,
                   dismissed=None,
                   dismissed_before=None,
                   dismissed_after=None,
                   archived=None,
                   archived_before=None,
                   archived_after=None,
                   page=None):
        return self._list(created_after=created_after,
                          created_before=created_before,
                          id=entity_id,
                          user_id=user_id,
                          company_ids=company_ids,
                          person_ids=person_ids,
                          completed=completed,
                          completed_before=completed_before,
                          completed_after=completed_after,
                          dismissed=dismissed,
                          dismissed_before=dismissed_before,
                          dismissed_after=dismissed_after,
                          archived=archived,
                          archived_before=archived_before,
                          archived_after=archived_after,
                          page=page)

    def create(self, user_id=None,
                     action_type=None,
                     associated_entity_type=None,
                     associated_entity_id=None,
                     completed_at=None,
                     dismissed_at=None,
                     propensity_score=None,
                     content_items=[]):
        return self._create(user_id=user_id,
                            action_type=action_type,
                            associated_entity_type=associated_entity_type,
                            associated_entity_id=associated_entity_id,
                            completed_at=completed_at,
                            dismissed_at=dismissed_at,
                            propensity_score=propensity_score,
                            content_items=content_items)

    def fetch(self, entity_id):
        return self._fetch(entity_id)

    def update(self, entity_id,
                     user_id=None,
                     action_type=None,
                     associated_entity_type=None,
                     associated_entity_id=None,
                     completed_at=None,
                     dismissed_at=None,
                     archived_at=None,
                     propensity_score=None):
        return self._update(entity_id,
                            user_id=user_id,
                            action_type=action_type,
                            associated_entity_type=associated_entity_type,
                            associated_entity_id=associated_entity_id,
                            completed_at=completed_at,
                            dismissed_at=dismissed_at,
                            archived_at=archived_at,
                            propensity_score=propensity_score)

    def delete(self, entity_id):
        return self._delete(entity_id)



"""
hudai.resources.conference
"""
from ..helpers.resource import Resource


class ConferenceResource(Resource):
    def __init__(self, client):
        Resource.__init__(self, client, base_path='/people/conferences')
        self.resource_name = 'Conference'

    def list(self, name=None, person_id=None, before=None, after=None, company_id=None, page=None):
        return self._list(name=name,
                          person_id=person_id,
                          before=before,
                          after=after,
                          company_id=company_id,
                          page=page)

    def create(self, name=None, description=None, startsAt=None, endsAt=None, timezone=None, url=None):
        return self._create(name=name, description=description, startsAt=startsAt, endsAt=endsAt, timezone=timezone, url=url)

    def fetch(self, entity_id):
        return self._fetch(entity_id)

    def update(self, entity_id, name=None, description=None, startsAt=None, endsAt=None, timezone=None):
        return self._update(entity_id, name=name, description=description, startsAt=startsAt, endsAt=endsAt, timezone=timezone)

    def delete(self, entity_id):
        return self._delete(entity_id)



"""
hudai.resources.video
"""
from ..helpers.resource import Resource


class VideoResource(Resource):
    def __init__(self, client):
        Resource.__init__(self, client, base_path='/articles/videos')
        self.resource_name = 'Video'

    def search(self,
             max_importance=None,
             min_importance=None,
             person_id=None,
             company_id=None,
             source_id=None,
             published_after=None,
             published_before=None,
             created_after=None,
             created_before=None,
             video_group_id=None,
             page=None):
        return self.http_get('/search',
            query_params={
                'max_importance': max_importance,
                'min_importance': min_importance,
                'person_id': person_id,
                'company_id': company_id,
                'source_id': source_id,
                'published_after': published_after,
                'published_before': published_before,
                'created_after': created_after,
                'created_before': created_before,
                'video_group_id': video_group_id,
                'page': page,
            }
        )

    def list(self,
             importance_score_min=None,
             person_id=None,
             company_id=None,
             source_id=None,
             published_after=None,
             published_before=None,
             video_group_id=None,
             page=None):
        return self._list(
            importance_score_min=importance_score_min,
            person_id=person_id,
            company_id=company_id,
            source_id=source_id,
            published_after=published_after,
            published_before=published_before,
            video_group_id=video_group_id,
            page=page
        )

    def create(self,
               title=None,
               description=None,
               transcript=None,
               poster_url=None,
               video_url=None,
               importance_score=None,
               published_at=None,
               video_group_id=None):
        return self._create(
            title=title,
            description=description,
            importance_score=importance_score,
            transcript=transcript,
            published_at=published_at,
            poster_url=poster_url,
            video_url=video_url,
            video_group_id=video_group_id
        )

    def fetch(self, entity_id):
        return self._fetch(entity_id)

    def update(self, entity_id,
               title=None,
               description=None,
               transcript=None,
               poster_url=None,
               video_url=None,
               importance_score=None,
               published_at=None,
               video_group_id=None):
        return self._update(
            entity_id,
            title=title,
            description=description,
            importance_score=importance_score,
            transcript=transcript,
            published_at=published_at,
            poster_url=poster_url,
            video_url=video_url,
            video_group_id=video_group_id
        )

    def delete(self, entity_id):
        return self._delete(entity_id)




from ..helpers.resource import Resource


class FeedResource(Resource):
    def __init__(self, client):
        Resource.__init__(self, client, base_path='/users/feed')
        self.resource_name = 'Feed'

    def list(
        self,
        user_id,
        company_ids=None,
        key_terms=None,
        max_importance=None,
        max_relevance=None,
        min_importance=None,
        min_relevance=None,
        published_after=None,
        published_before=None,
        scored_after=None,
        scored_before=None,
        source_ids=None,
        tags=None,
        geographies=None,
        text=None,
        types=None,
        weights=None,
        page=None
    ):
        return self._list(
            user_id=user_id,
            company_ids=company_ids,
            key_terms=key_terms,
            max_importance=max_importance,
            max_relevance=max_relevance,
            min_importance=min_importance,
            min_relevance=min_relevance,
            published_after=published_after,
            published_before=published_before,
            scored_after=scored_after,
            scored_before=scored_before,
            source_ids=source_ids,
            tags=tags,
            geographies=geographies,
            text=text,
            types=types,
            weights=weights,
            page=page
        )



"""
hudai.resources.video_person
"""
from ..helpers.resource import Resource


class VideoPersonResource(Resource):
    def __init__(self, client):
        Resource.__init__(self, client, base_path='/articles/videos/people')
        self.resource_name = 'VideoPerson'

    def list(self, video_id=None, person_id=None, page=None):
        return self._list(
            video_id=video_id,
            person_id=person_id,
            page=page
        )

    def create(self, video_id, person_id):
        return self._create(
            video_id=video_id,
            person_id=person_id
        )

    def delete(self, video_id, person_id):
        return self.http_delete('/',
                                query_params={
                                    'video_id': video_id,
                                    'person_id': person_id
                                })
